# Changelog

## 1.0.0-rc7 (2025-11-07)

Full Changelog: [v1.0.0-rc6...v1.0.0-rc7](https://github.com/Not-Diamond/not-diamond-python/compare/v1.0.0-rc6...v1.0.0-rc7)

### Features

* **api:** api update ([bdb1ebe](https://github.com/Not-Diamond/not-diamond-python/commit/bdb1ebe855fe24f1c9d93804fea1ef38ae77341d))

## 1.0.0-rc6 (2025-11-06)

Full Changelog: [v1.0.0-rc5...v1.0.0-rc6](https://github.com/Not-Diamond/not-diamond-python/compare/v1.0.0-rc5...v1.0.0-rc6)

### Features

* **api:** manual updates ([e864113](https://github.com/Not-Diamond/not-diamond-python/commit/e864113c227997b0c04a02cad05b8963fe5a9283))

## 1.0.0-rc5 (2025-11-05)

Full Changelog: [v1.0.0-rc4...v1.0.0-rc5](https://github.com/Not-Diamond/not-diamond-python/compare/v1.0.0-rc4...v1.0.0-rc5)

### Features

* **api:** manual updates ([0a7ac49](https://github.com/Not-Diamond/not-diamond-python/commit/0a7ac4986879837b1b93bb31c5b7e6d211a55077))


### Chores

* update SDK settings ([227346c](https://github.com/Not-Diamond/not-diamond-python/commit/227346c8e801e2ee7f0f7c376fb55e5aea606232))

## 1.0.0-rc4 (2025-11-05)

Full Changelog: [v1.0.0-rc3...v1.0.0-rc4](https://github.com/Not-Diamond/not-diamond-python/compare/v1.0.0-rc3...v1.0.0-rc4)

### Features

* **api:** manual updates ([dd9657d](https://github.com/Not-Diamond/not-diamond-python/commit/dd9657df2226d7d46cf99ee8b23eced653155c74))

## 1.0.0-rc3 (2025-11-05)

Full Changelog: [v1.0.0-rc2...v1.0.0-rc3](https://github.com/Not-Diamond/not-diamond-python/compare/v1.0.0-rc2...v1.0.0-rc3)

### Features

* **api:** api update ([0cdedc2](https://github.com/Not-Diamond/not-diamond-python/commit/0cdedc27ef1bab63e433bdc0717c36cc48d60b55))
* **api:** api update ([f717b91](https://github.com/Not-Diamond/not-diamond-python/commit/f717b91a37cd48a63e9ef9458cef6dd899383f2c))
* **api:** api update ([24340ab](https://github.com/Not-Diamond/not-diamond-python/commit/24340ab121937a85e9c4bbc8b644c62b15f75d89))
* **api:** enable tests ([64ccd03](https://github.com/Not-Diamond/not-diamond-python/commit/64ccd03281ae7b420b44cf64910568e3657f24db))
* **api:** regen docs ([c80dbe1](https://github.com/Not-Diamond/not-diamond-python/commit/c80dbe1994cd73b549995b5e91ac86a62a77f5b7))
* **api:** verify mock tests enabled ([638d79b](https://github.com/Not-Diamond/not-diamond-python/commit/638d79bdd90097d9823d02e3dac8b12ab2849d03))


### Chores

* **internal:** grammar fix (it's -&gt; its) ([6d37a12](https://github.com/Not-Diamond/not-diamond-python/commit/6d37a125457223046183bcc8ee7159ed96b80424))
* update SDK settings ([ba3968b](https://github.com/Not-Diamond/not-diamond-python/commit/ba3968b9ef7b2ec9e7b1b3983a6e2a8b31ccbc37))

## 1.0.0-rc2 (2025-10-31)

Full Changelog: [v1.0.0-rc1...v1.0.0-rc2](https://github.com/Not-Diamond/not-diamond-python/compare/v1.0.0-rc1...v1.0.0-rc2)

### Features

* **api:** api update ([f4f83bd](https://github.com/Not-Diamond/not-diamond-python/commit/f4f83bd926d4296f883f5db75de90a5db275867a))

## 1.0.0-rc1 (2025-10-31)

Full Changelog: [v0.3.0...v1.0.0-rc1](https://github.com/Not-Diamond/not-diamond-python/compare/v0.3.0...v1.0.0-rc1)

### Features

* **api:** fix modelSelect error ([eb29990](https://github.com/Not-Diamond/not-diamond-python/commit/eb29990fab14468f39368f7f5b0e4ebf019d0841))
* **api:** manual updates ([b905d72](https://github.com/Not-Diamond/not-diamond-python/commit/b905d72ebec4d42373de62865a85f62d4a87c477))
* **api:** manual updates ([d664d8d](https://github.com/Not-Diamond/not-diamond-python/commit/d664d8d20ab802a9aa0150519a3900d386f7b1d9))


### Bug Fixes

* **client:** close streams without requiring full consumption ([c9f7310](https://github.com/Not-Diamond/not-diamond-python/commit/c9f73103e1747f06da439c77b7d5e322c4d09a4e))


### Chores

* **internal/tests:** avoid race condition with implicit client cleanup ([14e720b](https://github.com/Not-Diamond/not-diamond-python/commit/14e720b4d735b9a52d634b1ec24db5bff9c3aa24))
* update SDK settings ([26ae314](https://github.com/Not-Diamond/not-diamond-python/commit/26ae3141eaa1df28dd8b1d1e5d322fb135bee6b9))

## 0.3.0 (2025-10-24)

Full Changelog: [v0.2.0...v0.3.0](https://github.com/Not-Diamond/not-diamond-python/compare/v0.2.0...v0.3.0)

### Features

* **api:** api update ([d403264](https://github.com/Not-Diamond/not-diamond-python/commit/d4032647605736f1c51d04023d3adb24f448737f))
* **api:** api update ([c7a1198](https://github.com/Not-Diamond/not-diamond-python/commit/c7a1198c1432e833b740f92df9996379f941228f))
* **api:** api update ([9265a0a](https://github.com/Not-Diamond/not-diamond-python/commit/9265a0a3959818b06f157726e68d3c73f7f5d9c9))
* **api:** api update ([880c195](https://github.com/Not-Diamond/not-diamond-python/commit/880c195dc41ac5e500cae9b9a71b0840f97e7556))
* **api:** exclude non sdk endpoints ([fb04bc4](https://github.com/Not-Diamond/not-diamond-python/commit/fb04bc460d7f9f7f191cffcb56868d09fa45edc1))
* **api:** fix missing endpoint ([427d1d3](https://github.com/Not-Diamond/not-diamond-python/commit/427d1d3bdd7be290e66897aa35daba984931e4a4))
* **api:** manual updates ([603c1b7](https://github.com/Not-Diamond/not-diamond-python/commit/603c1b74c64850e1fd8a89e08b1d66d0665188e0))
* **api:** manual updates ([42fb39e](https://github.com/Not-Diamond/not-diamond-python/commit/42fb39e0978aa329f4b5171ff54aaab257558135))
* **api:** report group ([4312188](https://github.com/Not-Diamond/not-diamond-python/commit/43121880104978fa2b88a3ad0e85070a2b322787))


### Chores

* bump `httpx-aiohttp` version to 0.1.9 ([37d5de2](https://github.com/Not-Diamond/not-diamond-python/commit/37d5de2162ece6024539d9e546dd2679ba5e1882))
* **internal:** detect missing future annotations with ruff ([316a749](https://github.com/Not-Diamond/not-diamond-python/commit/316a7493d166e631eafcc888d377dbe340178b24))

## 0.2.0 (2025-10-09)

Full Changelog: [v0.1.0...v0.2.0](https://github.com/Not-Diamond/not-diamond-python/compare/v0.1.0...v0.2.0)

### Features

* **api:** manual updates ([9ee8b3e](https://github.com/Not-Diamond/not-diamond-python/commit/9ee8b3e1220e45b00ce9c9078ab7f54bb1e34e19))

## 0.1.0 (2025-10-09)

Full Changelog: [v0.0.1...v0.1.0](https://github.com/Not-Diamond/not-diamond-python/compare/v0.0.1...v0.1.0)

### Features

* **api:** manual updates ([8062369](https://github.com/Not-Diamond/not-diamond-python/commit/80623692c7da0db7c57b7953af3ec9fdc1e0fca2))


### Chores

* update SDK settings ([ecc0dc6](https://github.com/Not-Diamond/not-diamond-python/commit/ecc0dc63a8d98e9d2178f04cebde730257bae353))
